@@ -126,12 +126,12 @@ object SpecificUnitAutomation {
                 .firstOrNull()?.action?.invoke()
     }
 
-    fun automateSettlerActions(unit: MapUnit) {
+    fun automateSettlerActions(unit: MapUnit, tilesWhereWeWillBeCaptured: Set<Tile>) {
         if (unit.civ.gameInfo.turns == 0) {   // Special case, we want AI to settle in place on turn 1.
             val foundCityAction = UnitActions.getFoundCityAction(unit, unit.getTile())
             // Depending on era and difficulty we might start with more than one settler. In that case settle the one with the best location
             val otherSettlers = unit.civ.units.getCivUnits().filter { it.currentMovement > 0 && it.baseUnit == unit.baseUnit }
-            if(foundCityAction?.action != null &&
+            if (foundCityAction?.action != null &&
                     otherSettlers.none {
                         CityLocationTileRanker.rankTileAsCityCenter(
                             it.getTile(), unit.civ
@@ -145,14 +145,11 @@ object SpecificUnitAutomation {
             }
         }
 
-        if (unit.getTile().militaryUnit == null     // Don't move until you're accompanied by a military unit
-            && !unit.civ.isCityState()          // ..unless you're a city state that was unable to settle its city on turn 1
-            && unit.getDamageFromTerrain() < unit.health) return    // Also make sure we won't die waiting
-
         // It's possible that we'll see a tile "over the sea" that's better than the tiles close by, but that's not a reason to abandon the close tiles!
         // Also this lead to some routing problems, see https://github.com/yairm210/Unciv/issues/3653
         val bestCityLocation: Tile? =
                 CityLocationTileRanker.getBestTilesToFoundCity(unit).firstOrNull {
+                    if (it.first in tilesWhereWeWillBeCaptured) return@firstOrNull false
                     val pathSize = unit.movement.getShortestPath(it.first).size
                     return@firstOrNull pathSize in 1..3
                 }?.first
@@ -169,7 +166,7 @@ object SpecificUnitAutomation {
             if (frontierCity != null && getFrontierScore(frontierCity) > 0  && unit.movement.canReach(frontierCity.getCenterTile()))
                 unit.movement.headTowards(frontierCity.getCenterTile())
             if (UnitAutomation.tryExplore(unit)) return // try to find new areas
-            UnitAutomation.wander(unit) // go around aimlessly
+            UnitAutomation.wander(unit, tilesToAvoid = tilesWhereWeWillBeCaptured) // go around aimlessly
             return
         }
 
@@ -260,13 +257,17 @@ object SpecificUnitAutomation {
         val closestCityStateTile =
                 unit.civ.gameInfo.civilizations
                     .filter {
-                        !unit.civ.isAtWarWith(it) && it.isCityState() && it.cities.isNotEmpty()
+                        it != unit.civ
+                            && !unit.civ.isAtWarWith(it)
+                            && it.isCityState()
+                            && it.cities.isNotEmpty()
                     }
                     .flatMap { it.cities[0].getTiles() }
                     .filter { unit.civ.hasExplored(it) }
                     .mapNotNull { tile ->
                         val path = unit.movement.getShortestPath(tile)
-                        if (path.size <= 10) tile to path.size else null
+                        // 0 is unreachable, 10 is too far away
+                        if (path.size in 1..10) tile to path.size else null
                     }
                     .minByOrNull { it.second }?.first
                     ?: return false
@@ -295,18 +296,15 @@ object SpecificUnitAutomation {
      * of `false` can be interpreted as: the unit doesn't know where to go or is stuck. */
     fun speedupWonderConstruction(unit: MapUnit): Boolean {
         val nearbyCityWithAvailableWonders = unit.civ.cities.filter { city ->
-            // Maybe it would be nice to make space in the city if there's already some
-            // other civilian unit in there for whatever reason, but again that seems a lot of
-            // additional complexity for questionable gain.
+            // Don't speed up construction in small cities. There's a risk the great
+            // engineer can't get it done entirely and then it takes forever for the small
+            // city to finish the rest.
+            city.population.population >= 3 &&
             (unit.movement.canMoveTo(city.getCenterTile()) || unit.currentTile == city.getCenterTile())
-                    // Don't speed up construction in small cities. There's a risk the great
-                    // engineer can't get it done entirely and then it takes forever for the small
-                    // city to finish the rest.
-                    && city.population.population >= 3
                     && getWonderThatWouldBenefitFromBeingSpedUp(city) != null
         }.mapNotNull { city ->
             val path = unit.movement.getShortestPath(city.getCenterTile())
-            if (path.size <= 5) city to path.size else null
+            if (path.any() && path.size <= 5) city to path.size else null
         }.minByOrNull { it.second }?.first
 
         if (nearbyCityWithAvailableWonders == null) {
