@@ -143,19 +143,26 @@ class CivInfoTransientCache(val civInfo: Civilization) {
     /** Our tiles update pretty infrequently - most 'viewable tile' changes are due to unit movements,
      * which means we can store this separately and use it 'as is' so we don't need to find the neighboring tiles every time
      * a unit moves */
-    fun updateOurTiles(){
-        val newOurTilesAndNeighboring = HashSet<Tile>()
-        val ownedTiles = civInfo.cities.asSequence().flatMap { it.getTiles() }
-        newOurTilesAndNeighboring.addAll(ownedTiles)
-        val neighboringUnownedTiles = ownedTiles.flatMap { tile -> tile.neighbors.filter { it.getOwner() != civInfo } }
-        newOurTilesAndNeighboring.addAll(neighboringUnownedTiles)
-        ourTilesAndNeighboringTiles = newOurTilesAndNeighboring
+    fun updateOurTiles() {
+        ourTilesAndNeighboringTiles = civInfo.cities.asSequence()
+            .flatMap { it.getTiles() } // our owned tiles, still distinct
+            .flatMap { sequenceOf(it) + it.neighbors }
+            // now we got a mix of owned, unowned and competitor-owned tiles, and **duplicates**
+            // but Sequence.toSet is just as good at making them distinct as any other operation
+            .toSet()
 
         updateViewableTiles()
         updateCivResources()
     }
 
     private fun setNewViewableTiles() {
+        if (civInfo.isDefeated()) {
+            // Avoid meeting dead city states when entering a tile owned by their former ally (#9245)
+            // In that case ourTilesAndNeighboringTiles and getCivUnits will be empty, but the for
+            // loop getKnownCivs/getAllyCiv would add tiles.
+            civInfo.viewableTiles = emptySet()
+            return
+        }
 
         // while spectating all map is visible
         if (civInfo.isSpectator() || DebugUtils.VISIBLE_MAP) {
@@ -206,9 +213,10 @@ class CivInfoTransientCache(val civInfo: Civilization) {
             if (civInfo.naturalWonders.contains(tile.naturalWonder))
                 continue
             civInfo.naturalWonders.add(tile.naturalWonder!!)
-            if(!civInfo.isSpectator())
-                civInfo.addNotification("We have discovered [${tile.naturalWonder}]!",
-                    tile.position, NotificationCategory.General, "StatIcons/Happiness")
+            if (civInfo.isSpectator()) continue // don't trigger anything
+
+            civInfo.addNotification("We have discovered [${tile.naturalWonder}]!",
+                tile.position, NotificationCategory.General, "StatIcons/Happiness")
 
             var goldGained = 0
             val discoveredNaturalWonders = civInfo.gameInfo.civilizations.filter { it != civInfo && it.isMajorCiv() }
@@ -233,8 +241,6 @@ class CivInfoTransientCache(val civInfo: Civilization) {
                 StateForConditionals(civInfo, tile = tile)
             ))
                 UniqueTriggerActivation.triggerCivwideUnique(unique, civInfo, tile=tile, triggerNotificationText = "due to discovering a Natural Wonder")
-
-
         }
     }
 
@@ -272,7 +278,7 @@ class CivInfoTransientCache(val civInfo: Civilization) {
         for (city in civInfo.cities) newDetailedCivResources.add(city.getCityResources())
 
         for (resourceSupply in newDetailedCivResources)
-            if(resourceSupply.amount > 0)
+            if (resourceSupply.amount > 0)
                 resourceSupply.amount = (resourceSupply.amount * civInfo.getResourceModifier(resourceSupply.resource)).toInt()
 
         if (!civInfo.isCityState()) {
@@ -305,13 +311,13 @@ class CivInfoTransientCache(val civInfo: Civilization) {
 
         for (unit in civInfo.units.getCivUnits())
             newDetailedCivResources.subtractResourceRequirements(
-                unit.baseUnit.getResourceRequirements(), civInfo.gameInfo.ruleset, "Units")
+                unit.baseUnit.getResourceRequirementsPerTurn(), civInfo.gameInfo.ruleset, "Units")
 
         // Check if anything has actually changed so we don't update stats for no reason - this uses List equality which means it checks the elements
         if (civInfo.detailedCivResources == newDetailedCivResources) return
 
         civInfo.detailedCivResources = newDetailedCivResources
-        civInfo.summarizedCivResources = newDetailedCivResources.sumByResource("All")
+        civInfo.summarizedCivResourceSupply = newDetailedCivResources.sumByResource("All")
 
         civInfo.updateStatsForNextTurn() // More or less resources = more or less happiness, with potential domino effects
     }
